@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1998  Paul Wilkins
+Copyright (C) 2000  Paul Wilkins
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -40,10 +40,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define FONT6 "fixed"
 
 
-/* the ideal starting values */
-#define LCD_WIDTH 400
-#define LCD_HEIGHT 200
-
 /* the amount of spacing we want around the display */
 #define BORDER 2 
 
@@ -109,7 +105,10 @@ void lcdContinueHighlight(int x, int y);
 #define TARGET_TEXT 0x2
 #define TARGET_COMPOUND_TEXT 0x4
 
-GtkWidget *setupLCD(GtkWidget *parent){
+GtkWidget *setupLCD(GtkWidget *parent, int rows, int cols, char *font){
+   int i;
+   int width;
+   int wid, hgt;
 #ifdef GTK_VER_1_1
    static GtkTargetEntry targetlist[] = {
      /* Target          Flags  Info      */
@@ -120,9 +119,47 @@ GtkWidget *setupLCD(GtkWidget *parent){
    static gint ntargets = sizeof(targetlist) / sizeof(targetlist[0]);
 #endif
 
+   /* store arguments */
+   lcdWidth = cols;
+   lcdHeight = rows;
+
+   /* get a font for the main window */
+   if(font != NULL){
+      if(NULL == (lcdFont = gdk_font_load(font))){
+         fprintf(stderr, "Unable to load font %s.\n", font);
+         exit(0);
+      }
+   } else if(NULL == (lcdFont = gdk_font_load(FONT1)) &&
+      NULL == (lcdFont = gdk_font_load(FONT2)) &&
+      NULL == (lcdFont = gdk_font_load(FONT3)) &&
+      NULL == (lcdFont = gdk_font_load(FONT4)) &&
+      NULL == (lcdFont = gdk_font_load(FONT5)) &&
+      NULL == (lcdFont = gdk_font_load(FONT6))){
+
+      fprintf(stderr, "Unable to load a font.\n");
+      exit(0);
+   }
+
+   /* find max font width */
+   for(i=0; i<256; i++){
+      width = gdk_char_width(lcdFont, (gchar)i);
+      if(width < 50 && width > fontW) fontW = width;
+   }
+
+   /* globals we use all over the place */
+   fontH = lcdFont->ascent + lcdFont->descent;
+   fontD = lcdFont->descent;
+
+   if(fontW == 0 || fontH == 0){
+      fprintf(stderr, "Error: can not determine font dimentions.\n");
+      exit(0);
+   }
+
+   wid = (2 * BORDER) + (lcdWidth * fontW);
+   hgt = (2 * BORDER) + (lcdHeight * fontH);
 
    lcdDA = gtk_drawing_area_new();
-   gtk_drawing_area_size(GTK_DRAWING_AREA(lcdDA), LCD_WIDTH, LCD_HEIGHT);
+   gtk_drawing_area_size(GTK_DRAWING_AREA(lcdDA), wid, hgt);
    gtk_box_pack_start(GTK_BOX(parent), lcdDA, TRUE, TRUE, 0);
    gtk_widget_show(lcdDA);
 
@@ -431,43 +468,6 @@ void redrawLCD(){
 }
 
 
-void lcdInitFont(){
-   int i, width;
-   GdkGCValues gc_values;
-
-   /* Create default Graphics Contexts */
-   /* highlight swaps foreground and background */
-   lcdGC = lcdDA->style->fg_gc[GTK_STATE_NORMAL];
-   lcdHighlightGC = lcdDA->style->bg_gc[GTK_STATE_NORMAL];
-
-   /* get a font for the main window */
-   if(NULL == (lcdFont = gdk_font_load(FONT1)) &&
-      NULL == (lcdFont = gdk_font_load(FONT2)) &&
-      NULL == (lcdFont = gdk_font_load(FONT3)) &&
-      NULL == (lcdFont = gdk_font_load(FONT4)) &&
-      NULL == (lcdFont = gdk_font_load(FONT5)) &&
-      NULL == (lcdFont = gdk_font_load(FONT6))){
-
-      fprintf(stderr, "Unable to load a font.\n");
-   }
-
-   /* find max font width */
-   for(i=0; i<256; i++){
-      width = gdk_char_width(lcdFont, (gchar)i);
-      if(width < 50 && width > fontW) fontW = width;
-   }
-
-   /* globals we use all over the place */
-   fontH = lcdFont->ascent + lcdFont->descent;
-   fontD = lcdFont->descent;
-
-   if(fontW == 0 || fontH == 0){
-      fprintf(stderr, "Error: can not determine font dimentions.\n");
-      exit(0);
-   }
-}
-
-
 void lcdResize(){
    int i;
    char *buf;
@@ -525,11 +525,20 @@ int getLCDDispMode(){
 }
 
 static gint lcdExposeCB(GtkWidget *widget, GdkEventExpose *event){
+   GtkStyle *style;
 
    if(lcdInitalized == 0){
-      lcdInitFont();
+
+      style = gtk_widget_get_style(widget);
+
+      /* Set the default Graphics Contexts */
+      /* highlight swaps foreground and background */
+      lcdGC = style->fg_gc[GTK_STATE_NORMAL];
+      lcdHighlightGC = style->bg_gc[GTK_STATE_NORMAL];
+
       lcdResize();
       lcdInitalized = 1;
+
    }
 
    clearLCDwindow();
@@ -789,7 +798,6 @@ void lcdStopHighlight(int x, int y, int time){
 	 dataSelected = NONE_SELECTED;
 	 drawStackLCD();
       }
-printf("lcdStopHighlight: calling gtk_selection_owner_set\n");
    }
 }
 
