@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1998  Paul Wilkins
+Copyright (C) 2000  Paul Wilkins
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -28,7 +28,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 extern int lcdWidth;
 extern int lcdHeight;
 
-GtkWidget *setupLCD(GtkWidget *);
+GtkWidget *setupLCD(GtkWidget *, int, int, char *);
 void redrawLCD();
 void clearLCD();
 
