@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1998  Paul Wilkins
+Copyright (C) 2000  Paul Wilkins
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -594,6 +594,50 @@ Number * powNumber(Number *a, Number *b){
    return c;
 }
 
+Number * ripNumber(Number *a, Number *b){
+   Number *c;
+   Number *num;
+   Number *den;
+
+   if(a == NULL || b == NULL) 
+      { fprintf(stderr, "ripNumber(NULL)\n"); exit(0); }
+
+   switch(a->type){
+      case REAL:
+      case COMPLEX:
+	 switch(b->type){
+	    case REAL:
+	    case COMPLEX:
+	       num = mulNumber(a,b);
+	       den = addNumber(a,b);
+	       c = divNumber(num,den);
+               freeNumber(num);
+               freeNumber(den);
+	       break;
+	    case MATRIX:
+	      invalidTyprError("rip");
+	      return NULL;
+	      break;
+	    default:
+	      fprintf(stderr, "Error: Unknown number type\n");
+	      exit(0);
+	      break;
+	 }
+	 break;
+      case MATRIX:
+	invalidTyprError("rip");
+	return NULL;
+	break;
+      default:
+	fprintf(stderr, "Error: Unknown number type\n");
+	exit(0);
+	break;
+   }
+
+   return c;
+}
+
+
 Number * mulNumber(Number *a, Number *b){
    Number *c = newNumber();
 
