@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1998  Paul Wilkins
+Copyright (C) 2000  Paul Wilkins
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -22,6 +22,16 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #ifndef __OPTIONS_H
 #define __OPTIONS_H
 
+/* toggle buttons in the dialog */
+extern GtkWidget *optBinBtn;
+extern GtkWidget *optOctBtn;
+extern GtkWidget *optDecBtn;
+extern GtkWidget *optHexBtn;
+
+/* the dialog */
+extern GtkWidget *optWindow;
+
+
 /* pops up a new window with all the options in it */
 void optionsCB(gpointer data);
 
